@@ -33,9 +33,7 @@ sub scan {
     $match ||= 1 if index($mhead->{'subject'}, 'Delivery Notification: ') == 0;
     return undef unless $match;
 
-    require Sisimai::Address;
     my $dscontents = [__PACKAGE__->DELIVERYSTATUS];
-    my @hasdivided = split("\n", $$mbody);
     my $rfc822part = '';    # (String) message/rfc822-headers part
     my $rfc822list = [];    # (Array) Each line in message/rfc822 part string
     my $blanklines = 0;     # (Integer) The number of blank lines
@@ -43,7 +41,7 @@ sub scan {
     my $recipients = 0;     # (Integer) The number of 'Final-Recipient' header
     my $v = undef;
 
-    for my $e ( @hasdivided ) {
+    for my $e ( split("\n", $$mbody) ) {
         # Read each line between the start of the message and the start of rfc822 part.
         unless( $readcursor ) {
             # Beginning of the bounce message or delivery status part
@@ -62,16 +60,15 @@ sub scan {
         }
 
         if( $readcursor & $Indicators->{'message-rfc822'} ) {
-            # After "message/rfc822"
+            # Inside of the original message part
             unless( length $e ) {
-                $blanklines++;
-                last if $blanklines > 1;
+                last if ++$blanklines > 1;
                 next;
             }
             push @$rfc822list, $e;
 
         } else {
-            # Before "message/rfc822"
+            # Error message part
             next unless $readcursor & $Indicators->{'deliverystatus'};
             next unless length $e;
 
@@ -97,7 +94,7 @@ sub scan {
 
             if( $e =~ /\A[ \t]+Recipient address:[ \t]*([^ ]+[@][^ ]+)\z/ ) {
                 #   Recipient address: kijitora@example.jp
-                if( length $v->{'recipient'} ) {
+                if( $v->{'recipient'} ) {
                     # There are multiple recipient addresses in the message body.
                     push @$dscontents, __PACKAGE__->DELIVERYSTATUS;
                     $v = $dscontents->[-1];
@@ -129,12 +126,12 @@ sub scan {
                 my $sessionlog = $2; # smtp session
                 $v->{'rhost'} = $remotehost;
 
-                if( $sessionlog =~ /\A[(]TCP|(.+)|\d+|(.+)|\d+[)]/ ) {
-                    # The value does not include ".", use IP address instead.
-                    # (TCP|17.111.174.67|47323|192.0.2.225|25)
-                    $v->{'lhost'} = $1;
-                    $v->{'rhost'} = $2 unless $remotehost =~ /[^.]+[.][^.]+/;
-                }
+                # The value does not include ".", use IP address instead.
+                # (TCP|17.111.174.67|47323|192.0.2.225|25)
+                next unless $sessionlog =~ /\A[(]TCP|(.+)|\d+|(.+)|\d+[)]/;
+                $v->{'lhost'} = $1;
+                $v->{'rhost'} = $2 unless $remotehost =~ /[^.]+[.][^.]+/;
+
             } else {
                 # Original-envelope-id: 0NFC009FLKOUVMA0@mr21p30im-asmtp004.me.com
                 # Reporting-MTA: dns;mr21p30im-asmtp004.me.com (tcp-daemon)
@@ -164,11 +161,10 @@ sub scan {
                     $v->{'lhost'}   = $localhost unless $v->{'lhost'} =~ /[^.]+[.][^ ]+/;
                 }
             }
-        } # End of if: rfc822
+        } # End of error message part
     }
     return undef unless $recipients;
 
-    require Sisimai::String;
     for my $e ( @$dscontents ) {
         $e->{'agent'}     = __PACKAGE__->smtpagent;
         $e->{'diagnosis'} = Sisimai::String->sweep($e->{'diagnosis'});
